@@ -1,15 +1,37 @@
 import os
+import sys
 from logging.config import dictConfig
 
-from python_agent.packages import urllib3
-from python_agent.packages.urllib3.exceptions import InsecureRequestWarning
+# Python 3.13 compatibility: handle potential import issues gracefully
+try:
+    from python_agent.packages import urllib3
+    from python_agent.packages.urllib3.exceptions import InsecureRequestWarning
 
-urllib3.disable_warnings(InsecureRequestWarning)
+    urllib3.disable_warnings(InsecureRequestWarning)
+except ImportError:
+    # Fallback for potential import issues on Python 3.13
+    try:
+        import urllib3
+        from urllib3.exceptions import InsecureRequestWarning
+
+        urllib3.disable_warnings(InsecureRequestWarning)
+    except ImportError:
+        # If urllib3 is not available, continue without warnings suppression
+        pass
 __legacy_mode__ = os.environ.get("SL_LEGACY_MODE", "false").lower() == "true"
 
-__version__ = "2.5.2"
+__version__ = "2.6.2"
 __package_name__ = "sealights-python-agent"
 
+# Python 3.13 support notification
+if sys.version_info >= (3, 13):
+    import logging
+
+    logger = logging.getLogger(__name__)
+    logger.debug(
+        f"Sealights Python Agent v{__version__} running on Python {sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}"
+    )
+
 ####################  PyNext Mode  ####################
 if not __legacy_mode__:
     is_debug = os.environ.get("SL_DEBUG", "false").lower() == "true"
