@@ -7,13 +7,14 @@ class AgentHeartbeatEvent(object):
         self.agentId = agent_id
         self.buildSessionId = config_data.buildSessionId
         self.appName = config_data.appName
-        self.events = [{
-            "type": AGENT_EVENT_HEARTBEAT,
-            "utcTimestamp_ms": get_utc_time_in_ms(),
-            "data": {
-                "agentInfo": {
-                    "labId": lab_id
-                },
-                "labId": lab_id
+        self.events = [
+            {
+                "type": AGENT_EVENT_HEARTBEAT,
+                "utcTimestamp_ms": get_utc_time_in_ms(),
+                "data": {"agentInfo": {"labId": lab_id}, "labId": lab_id},
             }
-        }]
+        ]
+
+    @property
+    def message_type(self):
+        return AGENT_EVENT_HEARTBEAT
